@@ -355,7 +355,7 @@ class TaskItemAssembler(Assembler):
             details = None if dto.details is None else [task_detail_assembler.to_entity(m) for m in dto.details],
             entry_time = None if dto.entry_time is None else UDate(dto.entry_time),
             exit_time = None if dto.exit_time is None else UDate(dto.exit_time),
-            exception = UStr(dto.exception)
+            exception = None if dto.exception is None else UStr(dto.exception)
         )
     def to_dto(self, x:TaskItem):
         return TaskItemDTO(
@@ -367,6 +367,6 @@ class TaskItemAssembler(Assembler):
             details = None if x.details is None else [task_detail_assembler.to_dto(m) for m in x.details],
             entry_time = None if x.entry_time is None else x.entry_time.get_value(),
             exit_time = None if x.exit_time is None else x.exit_time.get_value(),
-            exception = x.exception.get_value()
+            exception = None if x.exception is None else x.exception.get_value()
         )
 task_item_assembler=TaskItemAssembler()
